Thanks for stopping by to let us know something could be better!

Please run down the following list and make sure you've tried the usual "quick
fixes":

  - Search the issues already opened: https://github.com/{{metadata['repository']}}/issues
  - Search the issues on our "catch-all" repository: https://github.com/GoogleCloudPlatform/google-cloud-node
  - Search StackOverflow: http://stackoverflow.com/questions/tagged/google-cloud-platform+node.js

If you are still having issues, please be sure to include as much information as
possible:

#### Environment details

  - OS:
  - Node.js version:
  - npm version:
  - `{{ metadata['name'] }}` version:

#### Steps to reproduce

  1. ???
  2. ???

Following these steps will guarantee the quickest resolution possible.

Thanks!
